[cairo] [PATCH 6/7] surface: Make parameter naming consistent between header and impl

Bryce W. Harrington b.harrington at samsung.com
Wed Feb 26 14:29:42 PST 2014


This fixes this set of distcheck errors generating docs:

  src/cairo-surface.c:1668: warning: Parameter described in source code
  comment block but does not exist. FUNCTION:
  cairo_surface_set_device_scale Parameter: sx.

  src/cairo-surface.c:1668: warning: Parameter described in source code
  comment block but does not exist. FUNCTION:
  cairo_surface_set_device_scale Parameter: sy.

  src/cairo-surface.c:1668: warning: Parameter description for
  cairo_surface_set_device_scale::x_scale is missing in source code
  comment block.

  src/cairo-surface.c:1668: warning: Parameter description for
  cairo_surface_set_device_scale::y_scale is missing in source code
  comment block.

Signed-off-by: Bryce Harrington <b.harrington at samsung.com>
---
 src/cairo-surface.c |   12 ++++++------
 1 file changed, 6 insertions(+), 6 deletions(-)

diff --git a/src/cairo-surface.c b/src/cairo-surface.c
index d550131..8a11ca6 100644
--- a/src/cairo-surface.c
+++ b/src/cairo-surface.c
@@ -1650,8 +1650,8 @@ slim_hidden_def (cairo_surface_mark_dirty_rectangle);
 /**
  * cairo_surface_set_device_scale:
  * @surface: a #cairo_surface_t
  * @sx: a scale factor in the X direction
  * @sy: a scale factor in the Y direction
  *
  * Sets an scale that is multiplied to the device coordinates determined
  * by the CTM when drawing to @surface. One common use for this is to
@@ -1668,8 +1668,8 @@ slim_hidden_def (cairo_surface_mark_dirty_rectangle);
  **/
 void
 cairo_surface_set_device_scale (cairo_surface_t *surface,
-				double		 sx,
-				double		 sy)
+				double		 x_scale,
+				double		 y_scale)
 {
     cairo_status_t status;
 
@@ -1689,8 +1689,8 @@ cairo_surface_set_device_scale (cairo_surface_t *surface,
 	return;
     }
 
-    surface->device_transform.xx = sx;
-    surface->device_transform.yy = sy;
+    surface->device_transform.xx = x_scale;
+    surface->device_transform.yy = y_scale;
     surface->device_transform.xy = 0.0;
     surface->device_transform.yx = 0.0;
 
@@ -1650,8 +1650,8 @@ slim_hidden_def (cairo_surface_mark_dirty_rectangle);
  * cairo_surface_set_device_scale:
  * @surface: a #cairo_surface_t
- * @sx: a scale factor in the X direction
- * @sy: a scale factor in the Y direction
+ * @x_scale: a scale factor in the X direction
+ * @y_scale: a scale factor in the Y direction
  *
  * Sets an scale that is multiplied to the device coordinates determined
-- 
1.7.9.5


More information about the cairo mailing list